@@ -1,3 +1,5 @@
+from pyspark.sql import SparkSession
+spark = SparkSession.builder.getOrCreate()
 def get_dbutils(spark):
 	try:
 		from pyspark.dbutils import DBUtils
